Provider

Struct Provider 

#[repr(transparent)]
pub struct Provider { inner: TypedObjectRef<Provider, ()>, phantom: PhantomData<()>, }
GLib type: GObject with reference counted clone semantics.

Fields

inner: TypedObjectRef<Provider, ()>phantom: PhantomData<()>

Implementations

Source

impl Provider

pub fn id(&self) -> <Cell<u32> as Property>::Value

pub fn name(&self) -> <RefCell<String> as Property>::Value

pub fn set_name<'a>( &self, value: impl Borrow<<<RefCell<String> as Property>::Value as HasParamSpec>::SetValue>, )

pub fn period(&self) -> <Cell<u32> as Property>::Value

pub fn set_period<'a>( &self, value: impl Borrow<<<Cell<u32> as Property>::Value as HasParamSpec>::SetValue>, )

pub fn method(&self) -> <Cell<Method> as Property>::Value

pub fn set_method<'a>( &self, value: impl Borrow<<<Cell<Method> as Property>::Value as HasParamSpec>::SetValue>, )

pub fn default_counter(&self) -> <Cell<u32> as Property>::Value

pub fn set_default_counter<'a>( &self, value: impl Borrow<<<Cell<u32> as Property>::Value as HasParamSpec>::SetValue>, )

pub fn algorithm(&self) -> <Cell<Algorithm> as Property>::Value

pub fn set_algorithm<'a>( &self, value: impl Borrow<<<Cell<Algorithm> as Property>::Value as HasParamSpec>::SetValue>, )

pub fn digits(&self) -> <Cell<u32> as Property>::Value

pub fn set_digits<'a>( &self, value: impl Borrow<<<Cell<u32> as Property>::Value as HasParamSpec>::SetValue>, )

pub fn website(&self) -> <RefCell<Option<String>> as Property>::Value

pub fn set_website<'a>( &self, value: impl Borrow<<<RefCell<Option<String>> as Property>::Value as HasParamSpec>::SetValue>, )

pub fn help_url(&self) -> <RefCell<Option<String>> as Property>::Value

pub fn set_help_url<'a>( &self, value: impl Borrow<<<RefCell<Option<String>> as Property>::Value as HasParamSpec>::SetValue>, )

pub fn image_uri(&self) -> <RefCell<Option<String>> as Property>::Value

pub fn set_image_uri<'a>( &self, value: impl Borrow<<<RefCell<Option<String>> as Property>::Value as HasParamSpec>::SetValue>, )

pub fn remaining_time(&self) -> <Cell<u64> as Property>::Value

pub fn set_remaining_time<'a>( &self, value: impl Borrow<<<Cell<u64> as Property>::Value as HasParamSpec>::SetValue>, )

pub fn accounts_model(&self) -> <AccountsModel as Property>::Value

pub fn connect_id_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Listen for notifications of a change in the id property

pub fn connect_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the name property

pub fn connect_period_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the period property

pub fn connect_method_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the method property

pub fn connect_default_counter_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the default-counter property

pub fn connect_algorithm_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the algorithm property

pub fn connect_digits_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the digits property

pub fn connect_website_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the website property

pub fn connect_help_url_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the help-url property

pub fn connect_image_uri_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the image-uri property

pub fn connect_remaining_time_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the remaining-time property

pub fn connect_accounts_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Listen for notifications of a change in the accounts-model property

pub fn notify_id(&self)

Notify listeners of a change in the id property

pub fn notify_name(&self)

Notify listeners of a change in the name property

pub fn notify_period(&self)

Notify listeners of a change in the period property

pub fn notify_method(&self)

Notify listeners of a change in the method property

pub fn notify_default_counter(&self)

Notify listeners of a change in the default-counter property

pub fn notify_algorithm(&self)

Notify listeners of a change in the algorithm property

pub fn notify_digits(&self)

Notify listeners of a change in the digits property

pub fn notify_website(&self)

Notify listeners of a change in the website property

pub fn notify_help_url(&self)

Notify listeners of a change in the help-url property

pub fn notify_image_uri(&self)

Notify listeners of a change in the image-uri property

pub fn notify_remaining_time(&self)

Notify listeners of a change in the remaining-time property

pub fn notify_accounts_model(&self)

Notify listeners of a change in the accounts-model property

Source

impl Provider

pub fn create( name: &str, period: u32, algorithm: Algorithm, website: Option<String>, method: Method, digits: u32, default_counter: u32, help_url: Option<String>, image_uri: Option<String>, ) -> Result<Self>

pub fn load() -> Result<impl Iterator<Item = Self>>

pub fn new( id: u32, name: &str, period: u32, method: Method, algorithm: Algorithm, digits: u32, default_counter: u32, website: Option<String>, help_url: Option<String>, image_uri: Option<String>, ) -> Provider

pub async fn favicon( website: String, name: String, id: u32, ) -> Result<String, Box<dyn Error>>

pub fn delete(&self) -> Result<()>

pub fn update(&self, patch: &ProviderPatch) -> Result<()>

pub fn open_help(&self)

fn tick(&self)

fn setup_tick_callback(&self)

fn regenerate_otp(&self)

pub fn has_accounts(&self) -> bool

fn add_accounts(&self, accounts: &[Account])

pub fn add_account(&self, account: &Account)

pub fn find_accounts(&self, terms: &[String]) -> Vec<Account>

pub fn accounts(&self) -> &FilterListModel

pub fn filter(&self, text: String)

pub fn remove_account(&self, account: &Account)